import { Component, OnInit, Input } from '@angular/core';
import {FormControl, FormGroupDirective, NgForm, Validators} from '@angular/forms';
import {ErrorStateMatcher} from '@angular/material/core';

export class MyErrorStateMatcher implements ErrorStateMatcher {
  isErrorState(control: FormControl | null, form: FormGroupDirective | NgForm | null): boolean {
    const isSubmitted = form && form.submitted;
    return !!(control && control.invalid && (control.dirty || control.touched || isSubmitted));
  }
}


@Component({
  selector: 'gd-input',
  templateUrl: './gd-input.component.html',
  styleUrls: ['./gd-input.component.scss'],
})
export class GdInputComponent implements OnInit {

  @Input() color:any;
  @Input() placeholder:any;
  @Input() label:any;
  @Input() type:any;
  @Input() required:any;
  @Input() hint:any;

  emailFormControl:any;
  basicFormControl:any;
  matcher:any;

  constructor() { 
  }
  
  
  ngOnInit() {
    if(this.required && this.type == 'email'){
      this.emailFormControl = new FormControl('', [
        Validators.required,
        Validators.email,
      ]);
      this.matcher = new MyErrorStateMatcher();
    } 
    else if(!this.required && this.type == 'email'){
      this.emailFormControl = new FormControl('', [
        Validators.email,
      ])
      this.matcher = new MyErrorStateMatcher();      
    } 
    else if(this.required && this.type != 'email'){
      this.basicFormControl = new FormControl('', [
        Validators.required,
      ])
      this.matcher = new MyErrorStateMatcher();      
    }
    else{
      this.basicFormControl = new FormControl('', [
      ])
      this.matcher = new MyErrorStateMatcher();    
    }
  }

  checkName(){
    if(this.type == 'email'){
      return this.emailFormControl;
    } else{
      return this.basicFormControl;
    }
  }
  
}